# PG-backed DNS-Server
simple dns server using python
![example workflow](https://github.com/InnovAnon-Inc/import_db/actions/workflows/pkgrel.yml/badge.svg)

```sh
requirements:

dnslib
json
socket

```

# Setup
### Add your host where you want the server to run.
![add-host](https://user-images.githubusercontent.com/97550737/225977420-3b9a362b-f072-49c9-bfa1-6880584e49df.png)


# Usage  

```sh
python3 dns_server.py

```

# Innovations Anonymous
Free Code for a Free World!
==========
![Corporate Logo](https://innovanon-inc.github.io/assets/images/logo.gif)

